#!/usr/bin/perl

$outfile="ether.tex";
$pagfile="ether-pag.tex";
$title="Linux Ethernet Howto";
$author="Donald J. Becker and Paul Gortmaker";
$date="1.03 06/22/1994";

sub subsection {
    $quotechar="``";
    $squotechar="`";
    if ($newindent) {
	eval $newindent;
	undef $newindent;
    }
    print OF "\\subsection{$_[0]}\n";
}

sub section {
    $quotechar="``";
    $squotechar="`";
    if ($newindent) {
	eval $newindent;
	undef $newindent;
    }
    print OF "\\section{$_[0]}\n";
}

sub halign {
    $first=0;
    $e=shift @_;
    if (! $endhalign) {
	$endhalign = 'print OF "}\n";';
	print OF "\\hskip .5 true in\\halign{\\indent#\\hfil";
	foreach $dummy (@_) {
	    print OF "&\\qquad#\\hfil";
	}
	print OF "\\cr\n";
    }
    print OF "$e";
    while ($e=shift @_) {
	print OF "&$e";
    }
    print OF "\\cr\n";
}

sub enditem {
    print OF "\\end{description}\n";
}

sub indent {
    $count=0;
    @str=split (//,$_[0]);
    foreach $char (@str) {
	if ($char eq " ") {
	    $count=$count+1;
	} elsif ($char eq "\t") {
	    $count=$count+8;
	    $count =$count & ~7;
	} else {
	    return ($count);
	}
    }
    return ($count);
}

sub item {
    if (!$newindent || !$newindent =~ /enditem/) {
	$newindent = $newindent."&enditem();";
	print OF "\\begin{description}\n";
    }
    print OF "\\item{$_[0]} $_[1]\n";
}

open (OF, ">$outfile") || die "Unable to open $outfile";
print OF "\\input /home/biro/bible/$pagfile\n";
print OF "\\documentstyle[linuxdoc-sgml,qwertz,null]{article}\n";
print OF "\\title{$title}\n";
print OF "\\author{$author}\n";
print OF "\\date{$date}\n";
print OF "\\begin{document}\n";
print OF "\\part{$title}\n";
print OF "\\maketitle\n";
print OF "\\tableofcontents\n";
$quotechar="``";
$squotechar="`";
while (<>) {
    chop;
    $indent=&indent($_);
    if ($newindent && $indent != $oldindent) {
	eval $newindent;
	undef $newindent;
    }
    $oldindent=$indent;

    while (s/\"/$quotechar/) {
	if ($quotechar eq "``") {
	    $quotechar = "''";
	} else {
	    $quotechar="``";
	}
    }
    s/\{/\\\{/g;
    s/\}/\\\}/g;
    s/\*(\w+)\*/\{\\bf $1\}/g;
    s/_(\w+)_/\{\\bf $1\}/g;
    s/\*(\w+[ \']?\w*)\*/\{\\bf $1\}/g;
    s/\$/\\\$/g;
    s/_/\\_/g;
    s/&/\\&/g;
    s/#/\\#/g;
    s/->/-\$>\$/g;
    s/([^\$])</$1\$\\langle\$/g;
    s/([^\$])>/$1\$\\rangle\$/g;
    study $_;
    if (/^[0-9]+\.[0-9]+\s+/) {
	&subsection($');
    } elsif (/^[0-9]+\.?\s+/) {
	&section($');
    } elsif (/^\s+([^\t]+)\t+([^\t]+)$/) {
	&halign($1, $2);
    } elsif (/^\s+([^\t]+)\t+([^\t]+)\t+([^\t]+)$/) {
	&halign($1, $2, $3);
    } elsif(/^\s+(\(?[0-9]+\))/) {
	&item($1, $');
    } elsif(/^\s+(\w+:)/) {
	print OF "{\\bf $1}$'\n";
    } elsif (/^\s*=+\s*$/) {
	print OF "\\smallskip\\hrule\\smallskip\n";
    } else {
	if ($endhalign) {
	    eval $endhalign;
	    undef $endhalign;
	}
	s/^\s+//;
	print OF "$_\n";
    }
}

if ($newindent) {
    eval $newindent;
    undef $newindent;
}
print OF "\\end{document}\n";
close OF;
