#!/usr/bin/perl
# -*- perl -*-

$outfile="scsi.sgml";
$pagfile="scsi-pag.tex";
$title="Linux SCSI Howto";
$author="Drew Eckhardt drew@cs.colorado.edu";
$date="v 2.15 20 Mar 1995";

sub subsection {
    $quotechar="``";
    $squotechar="`";
    if ($newindent) {
	eval $newindent;
	undef $newindent;
    }
    print OF "<sect1>$_[0]\n";
}

sub section {
    $quotechar="``";
    $squotechar="`";
    if ($newindent) {
	eval $newindent;
	undef $newindent;
    }
    print OF "<sect>$_[0]\n";
}

sub halign {
    $first=0;
    $e=shift @_;
    if (! $endhalign) {
	$endhalign = 'print OF "}\n";';
	print OF "\\hskip .5 true in\\halign{\\indent#\\hfil";
	foreach $dummy (@_) {
	    print OF "&\\qquad#\\hfil";
	}
	print OF "\\cr\n";
    }
    print OF "$e";
    while ($e=shift @_) {
	print OF "&$e";
    }
    print OF "\\cr\n";
}

sub enditem {
    print OF "</itemize>\n";
}

sub indent {
    $count=0;
    @str=split (//,$_[0]);
    foreach $char (@str) {
	if ($char eq " ") {
	    $count=$count+1;
	} elsif ($char eq "\t") {
	    $count=$count+8;
	    $count =$count & ~7;
	} else {
	    return ($count);
	}
    }
    return ($count);
}

sub item {
    if (!$newindent || !$newindent =~ /enditem/) {
	$newindent = $newindent."&enditem();";
	print OF "<itemize>\n";
    }
    print OF "<item>$_[0] $_[1]\n";
}

open (OF, ">$outfile") || die "Unable to open $outfile";
print OF "<!doctype linuxdoc system>\n";
print OF "<article>\n";
print OF "<title>$title\n";
print OF "<author>$author\n";
print OF "<date>$date\n";
$quotechar="``";
$squotechar="`";
while (<>) {
    chop;
    $indent=&indent($_);
    if ($newindent && $indent != $oldindent) {
	eval $newindent;
	undef $newindent;
    }
    $oldindent=$indent;

    while (s/\"/$quotechar/) {
	if ($quotechar eq "``") {
	    $quotechar = "''";
	} else {
	    $quotechar="``";
	}
    }
    s/&/&amp/g;
    s/<\//&etago/g;
    s/</&lt/g;
    s/>/&gt/g;
    s/\$/&dollar/g;
    s/\#/&num/g;
    s/\%/&percent/g;
    study $_;
    if (/^Section\s+[0-9]+\.[0-9]+\s*:\s+/) {
	&subsection($');
    } elsif (/^Section\s+[0-9]+\.?\s*:\s+/) {
	&section($');
    } elsif (/^\s+([^\t]+)\t+([^\t]+)$/) {
	&halign($1, $2);
    } elsif (/^\s+([^\t]+)\t+([^\t]+)\t+([^\t]+)$/) {
	&halign($1, $2, $3);
    } elsif(/^\s+(\(?[0-9]+\))/) {
	&item($1, $');
    } elsif(/^\s+(\w+:)/) {
	print OF "{\\bf $1}$'\n";
    } elsif (/^\s*=+\s*$/) {
	print OF "\\smallskip\\hrule\\smallskip\n";
    } else {
	if ($endhalign) {
	    eval $endhalign;
	    undef $endhalign;
	}
	s/^\s+//;
	print OF "$_\n";
    }
}

if ($newindent) {
    eval $newindent;
    undef $newindent;
}
print OF "</article>\n";
close OF;
