#!/usr/bin/perl

# Randy Hootman 3/31/95

require "getopts.pl";

# The following arrays (%idx and %parts) are actually from mkb.pl.
# They are used here in case that, in the future, the subroutines 
# from this file could be merged into mkb.pl.


# %idx contains the initial .idx files used to create the %baseWordList

%idx=(
	'Installation and Getting Started', 'cat gs.idx',
	'Kernel Hackers Guide', 'cat khg.idx',
	'Network Administrators Guide', 'cat index/nag.idx',
	'Users Guide', 'cat guide.idx',
	'Printing Howto','printing.dvi ../info2idx.pl printing.pg printing.fn printing.cp',
      );

# %parts contains the complete list of the .tex files that need to be indexed
# based on %baseWordList. If the first field of the value portion is an *
# we need to get the .idx portion from the %idx array.
# The %parts array value is in the form $idx, $dir, $pagefile, $command.

%parts=(
	'Installation and Getting Started', '* install-guide-2.2.2 gs-page.tex latex gs.tex',
	'Plug and Play Manual','Yggdrasil . manual-pag.tex tex manual.texinfo >/dev/null; dvips -M -f <manual.dvi >/dev/null',
	'Kernel Hackers Guide', '* khg-0.6 khg-page.tex latex khg.tex',
	'Linux Programmers Guide', '* LPG lpg-page.tex latex lpg.tex',
	'Network Administrators Guide', '* TheGuide nag-page.tex make clean; make all',
	'System Administrators Guide', '* sag-0.2 sag-page.tex /usr/TeX/bin/latex sag.tex',
	'Users Guide', '* user-alpha-4 user-page.tex /usr/TeX/bin/latex guide.tex',
	'Lilo Users', 'LILO lilo lilou-pag.tex rm -f user.dvi; make user.dvi',
	'Lilo Tech', 'LILO lilo lilot-pag.tex rm -f tech.dvi; make tech.dvi',
	'Bootdisk Howto', 'bootdisk HOWTO-src bootdisk-pag.tex latex Bootdisk-HOWTO.tex',
	'Bus Mouse Howto', 'bus~mouse HOWTO-src busmouse-pag.tex latex Busmouse-HOWTO.tex',
	'CD-Rom Howto', 'CD-ROM HOWTO-src cdrom-pag.tex latex CDROM-HOWTO.tex',
	'Commercial Howto', 'commercial HOWTO-src commercial-pag.tex latex Commercial-HOWTO.tex',
	'Danish Howto', 'Danish HOWTO-src danish-pag.tex latex Danish-HOWTO.tex',
	'DOS Emulator Howto', 'DOSEMU HOWTO-src dosemu-pag.tex latex DOSEMU-HOWTO.tex',
	'Distribution Howto', '* HOWTO-src dist-pag.tex latex Distribution-HOWTO.tex',
	'Ethernet Howto', 'ethernet HOWTO-src ether-pag.tex latex Ethernet-HOWTO.tex',
	'Ftape Howto', 'ftape HOWTO-src ftape-pag.tex latex Ftape-HOWTO.tex',
	'Ham Howto', 'ham~radio HOWTO-SRC ham-pag.tex latex HAM-HOWTO.tex',
	'Hardware Howto', '* howtos hardware-pag.tex latex hardware.tex',
	'HOWTO-INDEX', '* HOWTO-src howtoidx-pag.tex latex HOWTO-INDEX.tex',
	'Installation Howto', 'installation HOWTO-src install-pag.tex latex Installation-HOWTO.tex',
	'Kernel Howto', 'kernel HOWTO-src kernel-pag.tex latex kernel-HOWTO.tex',
	'Japanese Extenstion (JE) Howto', 'Japanese howtos je-pag.tex latex je.tex',
	'Keystroke Howto', 'keymap howtos key-pag.tex latex key.tex',
	'MGR Howto', 'MGR HOWTO-src mgr-pag.tex latex MGR-HOWTO.tex',
	'Mail Howto', 'mail HOWTO-src mail-pag.tex latex Mail-HOWTO.tex',
	'Net2 Howto', 'networking HOWTO-src net2-pag.tex latex net-2-howto.tex',
	'NIS Howto', 'NIS HOWTO-src nis-pag.tex latex NIS-HOWTO.tex',
	'Usenet News Howto', 'news HOWTO-src news-pag.tex latex News-HOWTO.tex',
	'PCMCIA Howto', 'pcmcia HOWTO-src pcmcia-pag.tex latex PCMCIA-HOWTO.tex',
	'PPP Howto', 'ppp HOWTO-src ppp-pag.tex latex PPP-HOWTO.tex',
	'PCI Howto', 'PCI HOWTO-src pci-pag.tex latex PCI-HOWTO.tex',
	'Printing Howto','printing howtos printing-pag.tex tex printing.texinfo',
	'SCSI Howto', 'SCSI howtos scsi-pag.tex latex scsi.tex',
	'SCSI Programming Howto', 'SCSI HOWTO-SRC scsihowto-pag.tex latex SCSI-Programming-HOWTO.tex',
	'Serial Howto', 'serial HOWTO-src serial-pag.tex latex Serial-HOWTO.tex',
	'Sound Howto', 'sound HOWTO-src sound-pag.tex latex Sound-HOWTO.tex',
	'Term Howto', 'term HOWTO-src term-pag.tex latex Term-HOWTO.tex',
	'Tips Howto', '* HOWTO-src tips-pag.tex latex Tips-HOWTO.tex',
	'UUCP Howto', 'UUCP HOWTO-src uucp-pag.tex latex UUCP-HOWTO.tex',
	'WINE FAQ', 'WINE . wine-pag.tex latex wine.tex',
	'XFree86 Howto', 'XFree86 HOWTO-src xfree86-pag.tex latex XFree86-HOWTO.tex'
);

$usage = "\
Usage: mkidx.pl [-b]  -dstartdirectory \
\t-b     produces BaseWordList file \
\n";

# This is a list of words we are going to use to create indexes
%baseWordList = ();

# This is a list of words we don't want in the baseWordList
@stupidWordList = (A, a, The, the, In, in, user, User, users, Users, dummy, Dummy);

&HandleOptions;
&MakeBaseWordList;
&CreateIndexedTexFiles;
		
sub HandleOptions {
	&Getopts('bd:h');

	if ( $opt_h ) {
		die "$usage";
	}

	unless ( $opt_d ) {
		die "$usage";
	}

	$startdir = $opt_d;
}

sub MakeBaseWordList {

# Create the %baseWordList array from the .idx files in the %parts array.
# The words extracted from the  .idx files will be put into %baseWordList
# and used to index the other files.

	while (($key, $value) = each %parts) {

		($idx, $dir, $pagefile, $command)=split (/\s+/,$value,4);

		if ( $idx eq "*" ) {
			$idx = $idx{$key};

			if ( !$idx ) {
				next;
			}
		
			($bitbucket, $idx)=split (/\s+/,$idx,2);
			$filename = $dir . "/" . $idx;

			open (INPUT, "<$filename") || print "Can't open $filename\n";

			while ( <INPUT> ) {
				if (/{[a-zA-Z]+[^a-zA-Z]/) {
					$word = $&;
					substr($word,0,1)= '';
					chop $word;
					$baseWordList{$word}++;
				}
			}
			close INPUT;
		}
	}

# Filter out the words we do not want to appear in %baseWordList

	foreach $stupidWord (@stupidWordList) {
		delete $baseWordList{$stupidWord};
	}

	if ($opt_b) {
		@baseWordList = sort(keys %baseWordList);
		open (OUTPUT, "+>>BaseWordList");
		print OUTPUT "@baseWordList\n";
		close OUTPUT;
		print "BaseWordList created!\n";
	}
}

sub CreateIndexedTexFiles {

# Find all the .tex files in the starting directory and index them
# using the %baseWordList. Save the newly indexed .tex files as
# filename.tex.new

	opendir(START_DIR, $startdir) || die "Can't open the $startdir directory!\n";
	@allTexFiles = grep(/^.*.tex$/, readdir(START_DIR));
	closedir(HOWTO_DIR);

	for (@allTexFiles) {
	
		$filename = $startdir . "/" .  $_;
		open (INPUT, "<$filename") || print "Can't open $filename\n";;
		open (OUTPUT, "+>>$filename.new");
		
		while ( <INPUT> ) {
			@words = split(/\s+/,$_);
			foreach $word (@words) {
				$replstring = $word . "\\index" . "{" . $word . "}";
				if ( $baseWordList{$word} ) {
					s/\b$word\b/$replstring/g;
				}
			}
			print OUTPUT "$_";
		}
		close INPUT;
		close OUTPUT;
	}
}

